@@ -20,6 +20,12 @@
 #endif
 
 #include <QIcon>
+#include <QtPlugin>
+
+#if HAVE_OSM_PBF_SUPPORT
+Q_IMPORT_PLUGIN(OSM_PbfIOPlugin)
+#endif
+Q_IMPORT_PLUGIN(OSM_XmlIOPlugin)
 
 #ifdef Q_OS_ANDROID
 Q_DECL_EXPORT
