@@ -7,6 +7,8 @@
 #ifndef KOSMINDOORMAP_MAPCSSSTATE_P_H
 #define KOSMINDOORMAP_MAPCSSSTATE_P_H
 
+#include "mapcssobjecttype_p.h"
+
 #include <scene/openinghourscache_p.h>
 
 #include <osm/element.h>
@@ -20,6 +22,7 @@ public:
     OSM::Element element;
     double zoomLevel = 0.0;
     int floorLevel = 0;
+    MapCSSObjectType objectType = MapCSSObjectType::Any; // internal, set by MapCSSStyle
     OpeningHoursCache *openingHours = nullptr;
 };
 
